#
# spec file for package NetworkManager-pptp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pppd_plugin_dir %(rpm -ql ppp | grep -m1 pppd/[0-9]*)
Name:           NetworkManager-pptp
Version:        1.2.12
Release:        150600.2.2
Summary:        NetworkManager VPN support for PPTP
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://wiki.gnome.org/Projects/NetworkManager
Source0:        http://download.gnome.org/sources/NetworkManager-pptp/1.2/%{name}-%{version}.tar.xz

BuildRequires:  grep
BuildRequires:  intltool
BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  ppp-devel
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.32
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4
BuildRequires:  pkgconfig(gtk4) >= 4.0
BuildRequires:  pkgconfig(libnm) >= 1.2.0
BuildRequires:  pkgconfig(libnma) >= 1.2.0
BuildRequires:  pkgconfig(libnma-gtk4) >= 1.8.33
BuildRequires:  pkgconfig(libsecret-1) >= 0.18
Requires:       NetworkManager >= 1.2.0
Requires:       pptp
Supplements:    (NetworkManager and pptp)
%requires_eq    ppp

%description
NetworkManager-pptp provides VPN support to NetworkManager for PPTP.

%package -n NetworkManager-applet-pptp
Summary:        NetworkManager VPN support for PPTP
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-frontend = %{version}
Provides:       %{name}-gnome = %{version}
Obsoletes:      %{name}-gnome
Supplements:    (%{name} and NetworkManager-applet)
Supplements:    (%{name} and gnome-control-center)

%description -n NetworkManager-applet-pptp
NetworkManager-pptp provides VPN support to NetworkManager for PPTP.

%lang_package

%prep
%autosetup -p1

%build
%configure\
	--disable-static \
	--with-pppd-plugin-dir=%{pppd_plugin_dir} \
	--with-gtk4=yes \
	%{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%doc README
%{_libdir}/NetworkManager/libnm-vpn-plugin-pptp.so
%{_libexecdir}/nm-pptp-service
%{_vpnservicedir}/nm-pptp-service.name
%{_datadir}/dbus-1/system.d/nm-pptp-service.conf
%{pppd_plugin_dir}/nm-pptp-pppd-plugin.so

%files -n NetworkManager-applet-pptp
%{_datadir}/metainfo/network-manager-pptp.metainfo.xml
%{_libdir}/NetworkManager/libnm-vpn-plugin-pptp-editor.so
%{_libdir}/NetworkManager/libnm-gtk4-vpn-plugin-pptp-editor.so
%{_libexecdir}/nm-pptp-auth-dialog

%files lang -f %{name}.lang

%changelog
* Thu Mar 28 2024 songchuan.kang@suse.com
- Add missing supplements(bsc#1220391):
  + NMA subpackage: Main package and gnome-control-center
* Thu Nov  2 2023 gmbr3@opensuse.org
- Rename gnome subpackage to NetworkManager-applet-pptp
  to more accurately reflect its usage
- Add missing supplements:
  - NM and pptp
  - NMA subpackage: Main package and NMA
* Thu Mar  9 2023 bjorn.lie@gmail.com
- Update to version 1.2.12:
  + Dropped the libnm-glib support (obsolete since 2014).
  + Add support for building with upcoming pppd version (2.5.0).
  + Improvement to the build & test system.
  + Updated translations.
* Sat Mar 12 2022 bjorn.lie@gmail.com
- Update to version 1.2.10:
  + libnm-glib compatibility (NetworkManager < 1.0) is disabled by
    default.
  + It can be enabled by passing --with-libnm-glib to configure
    script. Nobody should need it by now. Users that still use this
    are encourage to let us know before the libnm-glib support is
    removed for good.
  + The auth helper in external UI mode can now be run without a
    display server. This is useful when activating connections with
    "nmcli --ask".
  + Gtk4 version of the editor plugin is now available (for use
    with Control Center of GNOME 42 or later).
  + Updated translations.
- Add pkgconfig(gtk4) and pkgconfig(libnma-gtk4) BuildRequires and
  pass --with-gtk4=yes to configure, build the gtk4 version.
- Stop passing --without-libnm-glib to configure, no longer
  needed, nor recognized.
- Add optional libxml2-tools BuildRequires, build runs
  xml-stripblanks preprocessing if available.
* Fri May  1 2020 dimstar@opensuse.org
- Set the path for the VPN service name file correctly to
  %%_vpnservicedir (provided by macros.NetworkManager).
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Thu Oct  4 2018 bjorn.lie@gmail.com
- Update to version 1.2.8:
  + Fix build without GTK/Gnome.
  + Updated translations.
* Sat Apr 14 2018 bjorn.lie@gmail.com
- Following changes in NetworkManager: pass without-libnm-glib to
  configure, no longer build deprecated libnm-glib support.
- Following the above changes: Drop no longer needed
  pkgconfig(NetworkManager), pkgconfig(libnm-glib),
  pkgconfig(libnm-glib-vpn), pkgconfig(libnm-gtk) and
  pkgconfig(libnm-util) BuildRequires.
- Package missing COPYING file.
- Package m-pptp-service.conf as config, silence rpmlint.
- Drop unnneeded NetworkManager-gnome Requires from gnome
  sub-package, it is not longer of use for us.
* Fri Mar 30 2018 luc14n0@linuxmail.org
- Update to version 1.2.6:
  + Fix passing "user" and set "remotename" (bgo#794695)
  + Use gresources for UI file
  + Updated translations.
- Update URL tag to https://wiki.gnome.org/Projects/NetworkManager:
  currently the Network Manager project's web page.
- Drop icon_theme_cache_* post/postun scriptlets: its fucntionality
  has been moved to RPM file triggers (4.13, suse_version 1330).
- Add gio-2.0, gio-unix-2.0 and glib-2.0 pkgconfig modules
  BuildRequires to avoid implicit dependencies.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Oct  4 2016 zaitor@opensuse.org
- Update to version 1.2.4:
  + Prefer building against stable libsecret API.
  + Split libnm-vpn-plugin-pptp.so into a GTK-free core plugin
    usable by nmcli and a UI plugin for nm-applet and gnome
    components.
  + Support NM_VPN_LOG_LEVEL environment variable to control debug
    logging from NetworkManager.
  + Various cleanups.
  + Updated translations.
- Replace pkgconfig(libsecret-unstable) for pkgconfig(libsecret-1)
  BuildRequires following upstreams changes.
- Drop NetworkManager-frontend Requires from main package.
* Sun May 15 2016 zaitor@opensuse.org
- Update to version 1.2.2:
  + Fixed the D-Bus API for multiple concurrent connections.
  + Use a proper name for the AppStream metadata.
  + Updated translations.
* Mon May  2 2016 dimstar@opensuse.org
- Update to version 1.2.0:
  + nm-pppd-plugin: fix crash.
  + Updated translations.
- Drop --disable-more-warnings from configure line: no longer
  needed.
* Thu Apr  7 2016 dimstar@opensuse.org
- Update to version 1.1.93 (1.2-rc1):
  + No changes.
- Changes from version 1.1.92:
  + Bugs fixed: bgo#762938.
  + Updated translations.
* Thu Apr  7 2016 dimstar@opensuse.org
- Update to version 1.1.91:
  + Updated translations.
* Thu Apr  7 2016 dimstar@opensuse.org
- Update to version 1.1.90:
  + Ported to libnm, libnma and GDBus.
  + Enhanced the GUI to support agent-owned and always-ask
    passwords.
  + Update the UI to use modern GTK witgets instead of deprecated
    ones.
  + Updated translations.
- Add pkgconfig(libnm) and pkgconfig(libnma) BuildRequires: new
  dependencies.
- Drop nm-pptp-desktop.patch: no longer needed.
- Drop icon sources: as there is no .desktop file, we also do not
  need an icon for it.
* Thu Apr  7 2016 sckang@suse.com
- Update to GNOME 3.20 Fate#318572
* Sun Nov 22 2015 zaitor@opensuse.org
- Update to version 1.0.8:
  + Updated translations.
* Tue Sep  1 2015 simon@simotek.net
- Update to version 1.0.6:
  + Enhanced the GUI to support agent-owned and always-ask
    passwords.
  + Updated translations.
* Wed May  6 2015 dimstar@opensuse.org
- Update to version 1.0.2:
  + Update the UI to use modern GTK witgets instead of deprecated
    ones.
  + Updated translations.
* Tue Jan 27 2015 dimstar@opensuse.org
- Update to version 1.0.0:
  + Updated translations.
* Tue Sep  9 2014 crrodriguez@opensuse.org
- Change ppp requires to %%requires_eq ppp: the plugin is installed
  in a versioned directory, and as such we do require the exact
  version of ppp (bnc#888442).
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 0.9.10.0:
  + Uses libsecret for password storage instead of gnome-keyring.
  + Fixes a potential crash when the plugin exits.
  + Ensure property dialog's translations show correctly in
    non-UTF-8 locales.
  + Updated translations.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-unstable), following upstreams switch to
  libsecret.
- Add pkgconfig(libnm-gtk) BuildRequires: new depdendency.
* Fri Sep 13 2013 dimstar@opensuse.org
- Update to version 0.9.8.4:
  + Fixed paths in VPN service file.
  + Fixed localization in non-UTF-8 locales.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 0.9.8.2:
  + Use full paths for auth dialog and properties plugin.
  + Updated translations.
* Fri Feb 22 2013 zaitor@opensuse.org
- Update to version 0.9.8.0:
  + Builds against the GNOME 3.8 versions of GLib and Gtk+.
  + nm-pptp-service now returns translated error messages.
  + Updated translations.
- Drop nm-pptp-deprecated-gtk.patch, fix upstream in a slightly
  different way.
- Drop libtool BuildRequires and call auto autoreconf, as we don't
  carry any patch touching the build system anymore.
* Fri Feb 15 2013 dimstar@opensuse.org
- Add nm-pptp-deprecated-gtk.patch: Do not disable deprecated GTK
  symbols for now (bgo#693866).
- Add libtool BuildRequires and call to autorecnf, as above patch
  touches the build system.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 0.9.6.0:
  + Update FSF Address.
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 0.9.5.95:
  + Fix sensitivity of auth methods when checking/unchecking MPPE
  + Updated translations.
* Sat Mar 24 2012 vuntz@opensuse.org
- Update to version 0.9.4.0:
  + Fix auth failure in some cases.
  + Updated translations.
* Fri Mar  2 2012 dimstar@opensuse.org
- Update to version 0.9.3.995:
  + Support for "external UI mode" for DE-native dialogs (ie, GNOME
    Shell and others)
  + Fix issues with password dialog width on recent GTK+ versions
  + Config dialog tooltips now refer to corresponding ppp/pptp
    config options
  + Updated translations.
- Add explicit pkgconfig(libnm-glib-vpn) BuildRequires: it's a long
  standing requirement which currently comes implicit with
  libnm-glib, as it's part of the same package at this moment.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Nov 12 2011 dimstar@opensuse.org
- Update to version 0.9.2.0:
  + Updated translations.
- Pass --disable-more-warnings to configure to allow building with
  gtk+ 3.3.
- Really enable parallel build: fix typo smp_flags => smp_mflags.
* Tue Nov  1 2011 dimstar@opensuse.org
- Update to version 0.9.1.95:
  + Updated translations.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile and strange
  ExcludeArch
* Tue Aug 23 2011 dimstar@opensuse.org
- Update to version 0.9.0:
  + Preserve secret flags.
  + Simplify keyring access and don't save secrets.
  + Use a simplified password request dialog.
  + Use gtk_box_new() instead of gtk_(h/v)box_new() (bgo#652801)
- Drop NetworkManager-pptp-gtk_box_new.patch: fixed upstream.
* Tue Jun 21 2011 dimstar@opensuse.org
- Add NetworkManager-pptp-gtk_box_new.patch: Fix build with GTK+
  3.1.6, which has gtk_{h|v}box_new deprecated. Patch taken from
  upstream git, commit id 81b8afb2.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 0.8.999:
  + Default to agent-owned secrets for new connections.
  + Updated translations.
* Thu Apr 21 2011 vuntz@opensuse.org
- Drop unneeded libglade2-devel, libgnomeui-devel,
  libgudev-1_0-devel, perl-XML-Parser, update-desktop-files
  BuildRequires.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: NetworkManager-devel, NetworkManager-gnome.
  + New ones: NetworkManager, dbus-glib-1, libnm-glib, libnm-util,
    gnome-keyring-1.
- Stop owning /etc/NetworkManager/VPN as it's owned by
  NetworkManager now.
* Tue Apr  5 2011 dimstar@opensuse.org
- Update to version 0.8.998 (0.9.0-rc1):
  + Bugs fixed: bgo#645909, lp#681739.
  + Updated translations.
* Wed Mar 16 2011 dimstar@opensuse.org
- Update to version 0.8.995 (0.9.0-beta1):
  + simpler, easier, more flexible, and cooler applets.
  + Fast User Switching.
  + WiMAX support.
  + System connections by default.
  + More flexible system administration.
  + Scales down to smaller devices.
- Add pkgconfig(gtk+-3.0) BuildRequires.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Remove ldconfig from %%post/%%postun: there is no library there.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 0.8.2:
  + Better debugging options
  + Updated for ppp 2.4.5
  + Updated translations.
- Split out -lang package.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.8.1:
  + Fix for MPPE and auth-method GUI jitter
  + Suppress some annoying PPTP warning messages
  + Updated translations
* Tue Feb 23 2010 dimstar@opensuse.org
- Update to version 0.8:
  + core: remove useless includes
  + build: disable .desktop file for now
  + deb#567461 - ui: fix saving of MPEE security levels
  + Translation updates.
* Sat Jan 30 2010 captain.magnus@opensuse.org
- Update to version 0.7.999:
  + Translation updates
* Thu Jan 21 2010 tambet@novell.com
- Upgrade to the latest upstream 0.8 branch:
  + Resolve pptp gateway hostname.
  + Fix MPPE EAP method combinations (bgo #596762).
  + Bug fixes.
  + Translation updates.
* Wed Dec 23 2009 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel, following the module split upstream.
* Thu Dec 10 2009 vuntz@opensuse.org
- Remove perl-XML-Parser BuildRequires.
- Do not call intltoolize and autoreconf.
* Thu Dec 10 2009 aj@suse.de
- Remove libgnomeui-devel BuildRequires.
* Fri Jun  5 2009 tambet@novell.com
- Upgrade to 0.7.1.
* Tue Nov 25 2008 bili@suse.de
- Fix dependencies(bnc#448119)
* Fri Nov  7 2008 bili@suse.de
- Update to r4274 from SVN.
* Fri Oct 24 2008 bili@suse.de
- Update to r4211 from SVN.
* Fri Sep 26 2008 ro@suse.de
- do not require exact release
* Wed Sep 17 2008 bili@suse.de
-  Update to r4060 from SVN.
* Fri May 16 2008 bili@suse.de
- Initial checkin, version in svn is 3842.(bnc#221466)
